@@ -1,12 +1,11 @@
 /* IPAllLayers.m
  * Layer management Inspector for all objects
  *
- * Copyright (C) 2002-2011 by vhf interservice GmbH
+ * Copyright (C) 2002-2005 by vhf interservice GmbH
  * Author:   Ilonka Fleischmann, Georg Fleischmann
  *
  * created:  2002-06-27
- * modified: 2011-01-10 (click on layer ends editing of text)
- *           2006-01-13
+ * modified: 2005-02-23
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -30,7 +29,6 @@
 #include "../App.h"
 #include "../DocView.h"
 #include "../LayerObject.h"
-#include "../LayerDetailsController.h"
 #include "../Graphics.h"
 #include "../messages.h"
 #include "InspectorPanel.h"
@@ -58,7 +56,7 @@
 }
 
 /* created:  1993-07-22
- * modified: 2006-01-13
+ * modified: 2003-06-28
  * purpose:  set layer list for layer matrix (moveMatrix)
  *           this may be called from self or from the document
  */
@@ -79,8 +77,7 @@
     lastLayerList = theLayerList;
     moveCellCount = [theLayerList count];
 
-    [moveMatrix setAllowsEmptySelection:YES];	// GNUstep: allows selectedRow = -1
-    //[moveMatrix selectCellAtRow:0 column:0];	// GNUstep
+    [moveMatrix selectCellAtRow:0 column:0];	// GNUstep
     [moveMatrix renewRows:0 columns:0];
     for (i=0, cnt=[theLayerList count]; i<cnt && (layerObject=[theLayerList objectAtIndex:i]); i++)
     {	[moveMatrix addRow];
@@ -90,7 +87,6 @@
     [moveMatrix sizeToCells];
     if ([moveMatrix numberOfRows])
         [moveMatrix selectCellAtRow:[docView indexOfSelectedLayer] column:0];
-    [moveMatrix setAllowsEmptySelection:NO];	// GNUstep
     [[moveMatrix superview] display];	// redraw clipView to be sure to overdraw removed cells
 
     if ((layerObject = [[moveMatrix selectedCell] layerObject]))
@@ -114,7 +110,7 @@
  */
 - (void)update:sender
 {
-    docView = [window docView];
+    docView = [[(App*)NSApp currentDocument] documentView];
 
     /* fill the layer matrix (moveMatrix) */
     [self setLayerList:(docView) ? [docView layerList] : [self currentLayerList]];
@@ -240,6 +236,7 @@
     [nameField setStringValue:[layerObject string]];
 
     [[docView document] setDirty:YES];
+    //[docView calcOutput];
     [docView drawAndDisplay];
 
     /* post notification, that layer xy has been removed, so other layer lists can update themselfes */
@@ -256,17 +253,15 @@
 
     /* update view */
     [[[(App*)NSApp currentDocument] documentView] selectLayerAtIndex:[self indexOfSelectedLayer]];
-
-    [[[(App*)NSApp currentDocument] window] endEditingFor:nil]; // end editing of text
 }
 
 - (void)doubleClickLayer:sender
-{   LayerObject	*layerObject = [self currentLayerObject];
+{   //LayerObject	*layerObject = [self currentLayerObject];
 
-    [[LayerDetailsController sharedInstance] showPanel:layerObject];
 }
 
-/* return YES, if at least one layer is displayed
+/*
+ * return YES, when at least one layer is displayed
  * called from IPLayerCell
  */
 - (BOOL)updateLayerLists
@@ -282,41 +277,23 @@
     return (cnt) ? YES : NO;
 }
 
-/* display new layers
+/*
+ * display new layers
  * called from IPLayerCell
- * modified: 2005-09-01
  */
 - (void)displayChanged:sender
 {   DocView		*view = [[(App*)NSApp currentDocument] documentView];
     int			l, i;
     NSMutableArray	*slayList = [view slayList], *layerList = [view layerList];
-    LayerObject		*selectedLayer = [[moveMatrix selectedCell] layerObject];
-    BOOL		layerStateChanged = NO;
 
     for ( l=0; l<(int)[layerList count]; l++ )
-    {   LayerObject	*layerObject = [layerList objectAtIndex:l];
-
-        if ( ![layerObject state] )
+        if ( ![[layerList objectAtIndex:l] state] )
         {   NSMutableArray	*slist = [slayList objectAtIndex:l];
 
             for (i=[slist count]-1; i>=0; i--)
                 [[slist objectAtIndex:i] setSelected:NO];
             [slist removeAllObjects];
         }
-        else if ([selectedLayer type] == LAYER_PAGE &&
-                 selectedLayer != layerObject && [layerObject type] == LAYER_PAGE)
-        {   NSMutableArray	*slist = [slayList objectAtIndex:l];
-
-            for (i=[slist count]-1; i>=0; i--)
-                [[slist objectAtIndex:i] setSelected:NO];
-            [slist removeAllObjects];
-
-            [layerObject setState:0];
-            layerStateChanged = YES;
-        }
-    }
-    if (layerStateChanged)	// redisplay layer list
-        [moveMatrix display];
     [view drawAndDisplay]; 
 }
 
