@@ -1,12 +1,12 @@
 /* GerberImport.m
  * Gerber import object (RS274X)
  *
- * Copyright (C) 1996-2003 by vhf interservice GmbH
+ * Copyright (C) 1996-2005 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *           Ilonka Fleischmann
  *
  * created:  1996-05-03
- * modified: 2002-10-26
+ * modified: 2005-05-12
  *
  * This file is part of the vhf Import Library.
  *
@@ -475,19 +475,19 @@ static void addToBeginNew(NSString *newOp, NSMutableString *beginNew)
     [scanner scanInt:&d];
     [scanner setScanLocation:location];
     if ( ([scanner scanString:ops.draw intoString:NULL] ||
-         [scanner scanString:ops.draw01 intoString:NULL]) && d==1 )
+         [scanner scanString:ops.draw01 intoString:NULL]) && d==1 ) // D01
     {
         state.lightCode = 1;
         return YES;
     }
     else if ( ([scanner scanString:ops.move intoString:NULL] ||
-              [scanner scanString:ops.move02 intoString:NULL]) && d==2)
+              [scanner scanString:ops.move02 intoString:NULL]) && d==2) // D02
     {
         state.lightCode = 2;
         return YES;
     }
     else if ( ([scanner scanString:ops.flash intoString:NULL] ||
-              [scanner scanString:ops.flash03 intoString:NULL]) && d==3 )
+              [scanner scanString:ops.flash03 intoString:NULL]) && d==3 ) // D03
     {
         state.lightCode = 3;
         state.draw = 1; /* x123y123D02* D03* */
@@ -508,14 +508,14 @@ static void addToBeginNew(NSString *newOp, NSMutableString *beginNew)
     {   [scanner scanUpToString:ops.termi intoString:NULL];
         [scanner scanString:ops.termi intoString:NULL];
     }
-    else if ( [scanner scanString:ops.polyBegin intoString:NULL] )	
+    else if ( [scanner scanString:ops.polyBegin intoString:NULL] ) // G36	
     {
         state.lightCode = 2; // off
         state.draw = 1;
         state.path = 1;
         state.g = Gerber_PATH;
     }
-    else if ( [scanner scanString:ops.polyEnd intoString:NULL] )	
+    else if ( [scanner scanString:ops.polyEnd intoString:NULL] ) // G37
     {
         state.lightCode = 2; // off
         state.path = 0;
@@ -612,8 +612,12 @@ static void addToBeginNew(NSString *newOp, NSMutableString *beginNew)
                     state.g = 0;
                     break;
                 default: /* off */
-                    state.point.x = state.x;
-                    state.point.y = state.y;
+                    if (state.path && [cList count])
+                        [self setLine:cList];
+                    else
+                    {   state.point.x = state.x;
+                        state.point.y = state.y;
+                    }
                     if ( state.path && state.g == Gerber_PATH )
                         [self setPath:scanner :cList];
                 state.g = 0;
@@ -1734,7 +1738,8 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
         p1.y = state.point.y + y;
     }
 
-    [self addLine:p0 :p1 toList:cList];
+    if (SqrDistPoints(p0, p1) > TOLERANCE*TOLERANCE)
+        [self addLine:p0 :p1 toList:cList];
 
     state.point = p1;
 
@@ -1944,6 +1949,9 @@ void replaceFromByTo(NSString** macroStr, NSString* from, NSString* to, int cnt,
     else
         angle = ea - ba;
 
+    if ( Diff(Abs(angle), 0.0) <= TOLERANCE || Diff(Abs(angle), 360.0) <= TOLERANCE )
+        angle = (angle > 0) ? 360.0 : -360.0;
+
     if ( state.ipolFull && Diff(angle, 360.0) <= TOLERANCE )
     {
         if ( state.path )
